###################################################
### chunk number 1: Init
###################################################
library("tm")
library("XML")


###################################################
### chunk number 2: 
###################################################
df <- data.frame(contents = c("content 1", "content 2", "content 3"),
                 title    = c("title 1"  , "title 2"  , "title 3"  ),
                 authors  = c("author 1" , "author 2" , "author 3" ),
                 topics   = c("topic 1"  , "topic 2"  , "topic 3"  ),
                 stringsAsFactors = FALSE)


###################################################
### chunk number 3: 
###################################################
names(attributes(PlainTextDocument()))


###################################################
### chunk number 4: Mapping
###################################################
m <- list(Content = "contents", Heading = "title",
          Author = "authors", Topic = "topics")


###################################################
### chunk number 5: myReader
###################################################
myReader <- readTabular(mapping = m)


###################################################
### chunk number 6: 
###################################################
(corpus <- Corpus(DataframeSource(df), readerControl = list(reader = myReader)))


###################################################
### chunk number 7: 
###################################################
corpus[[1]]
meta(corpus[[1]])


###################################################
### chunk number 8: CustomXMLFile
###################################################
custom.xml <- system.file("texts", "custom.xml", package = "tm")
print(readLines(custom.xml), quote = FALSE)


###################################################
### chunk number 9: mySource
###################################################
mySource <- function(x, encoding = "UTF-8")
    XMLSource(x, function(tree) XML::xmlRoot(tree)$children, myXMLReader, encoding)


###################################################
### chunk number 10: myXMLReader
###################################################
myXMLReader <- readXML(
    spec = list(Author = list("node", "/document/writer"),
                Content = list("node", "/document/description"),
                DateTimeStamp = list("function",
                                     function(x) as.POSIXlt(Sys.time(), tz = "GMT")),
                Description = list("attribute", "/document/@short"),
                Heading = list("node", "/document/caption"),
                ID = list("function", function(x) tempfile()),
                Origin = list("unevaluated", "My private bibliography"),
                Type = list("node", "/document/type")),
    doc = PlainTextDocument())


###################################################
### chunk number 11: 
###################################################
corpus <- Corpus(mySource(custom.xml))


###################################################
### chunk number 12: 
###################################################
corpus[[1]]
meta(corpus[[1]])


